package de.intevation.artifactdatabase;

import java.util.Properties;

import java.io.IOException;
import java.io.InputStream;

/**
 *  @author Sascha L. Teichmann
 */
public final class SQL
{
    private SQL() {
    }

    private static Properties statements;

    public static final synchronized Properties getStatements() {
        if (statements == null) {
            statements = loadStatements();
        }
        return statements;
    }

    private static final Properties loadStatements() {
        String driver = Config.getStringXPath(
            DBConnection.DB_DRIVER, DBConnection.DEFAULT_DRIVER);

        Properties properties = new Properties();

        InputStream in = null;
        try {
            String res = "/sql/" + driver.replace('.', '-').toLowerCase() 
                + ".properties";
            in = SQL.class.getResourceAsStream(res);

            if (in == null) {
                System.err.println("WARNING: no SQL file for driver '"
                    + driver + "' found.");
                res = "/sql/" + DBConnection.DEFAULT_DRIVER.replace('.', '-').toLowerCase()
                    + ".properties";
                if ((in = SQL.class.getResourceAsStream(res)) == null) {
                    System.err.println("ERROR: no SQL file found");
                }
            }

            properties.load(in);
        }
        catch (IOException ioe) {
            ioe.printStackTrace(System.err);
        }
        finally {
            if (in != null) {
                try { in.close(); } catch (IOException ioe) {}
            }
        }

        return properties;
    }

    public static final String get(String key) {
        return getStatements().getProperty(key);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
